==> qt-creator-2.1.0-src.tar.gz: qt-creator-2.1.0-src/src/plugins/texteditor/generichighlighter/highlightersettingspage.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** No Commercial Usage
**
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef HIGHLIGHTERSETTINGSPAGE_H
#define HIGHLIGHTERSETTINGSPAGE_H

#include "texteditoroptionspage.h"

QT_BEGIN_NAMESPACE
template <class> class QList;
QT_END_NAMESPACE

namespace TextEditor {

namespace Internal {
class HighlightDefinitionMetaData;
}

class HighlighterSettings;

class HighlighterSettingsPage : public TextEditorOptionsPage
{
    Q_OBJECT
public:
    HighlighterSettingsPage(const QString &id, QObject *parent);
    virtual ~HighlighterSettingsPage();

    QString id() const;
    QString displayName() const;

    QWidget *createPage(QWidget *parent);
    void apply();
    void finish() {}
    bool matches(const QString &s) const;

    const HighlighterSettings &highlighterSettings() const;

private slots:
    void resetDefinitionsLocation();
    void requestAvailableDefinitionsMetaData();
    void manageDefinitions(const QList<Internal::HighlightDefinitionMetaData> &metaData);
    void showError();
    void ignoreDownloadReply();
    void setFallbackLocationState(bool checked);
    void setDownloadDefinitionsState(bool valid);

private:
    void settingsFromUI();
    void settingsToUI();

    bool settingsChanged() const;

    bool m_requestMimeTypeRegistration;

    struct HighlighterSettingsPagePrivate;
    HighlighterSettingsPagePrivate *m_d;
};

} // namespace TextEditor

#endif // HIGHLIGHTERSETTINGSPAGE_H

==> qt-creator-2.6.2-src.tar.gz: qt-creator-2.6.2-src/src/plugins/texteditor/generichighlighter/highlightersettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef HIGHLIGHTERSETTINGSPAGE_H
#define HIGHLIGHTERSETTINGSPAGE_H

#include "texteditoroptionspage.h"

QT_BEGIN_NAMESPACE
template <class> class QList;
QT_END_NAMESPACE

namespace TextEditor {

namespace Internal {
class HighlightDefinitionMetaData;
}

class HighlighterSettings;

class HighlighterSettingsPage : public TextEditorOptionsPage
{
    Q_OBJECT

public:
    HighlighterSettingsPage(const QString &id, QObject *parent);
    ~HighlighterSettingsPage();

    QWidget *createPage(QWidget *parent);
    void apply();
    void finish();
    bool matches(const QString &s) const;

    const HighlighterSettings &highlighterSettings() const;

private slots:
    void resetDefinitionsLocation();
    void requestAvailableDefinitionsMetaData();
    void manageDefinitions(const QList<Internal::HighlightDefinitionMetaData> &metaData);
    void showError();
    void ignoreDownloadReply();
    void setFallbackLocationState(bool checked);
    void setDownloadDefinitionsState(bool valid);

private:
    void settingsFromUI();
    void settingsToUI();

    bool settingsChanged() const;

    bool m_requestMimeTypeRegistration;

    struct HighlighterSettingsPagePrivate;
    HighlighterSettingsPagePrivate *m_d;
};

} // namespace TextEditor

#endif // HIGHLIGHTERSETTINGSPAGE_H
